@@ -21,12 +21,13 @@ def dynamodb_autoscaling_enabled(self) -> dict:
     compliance_type = "Dynamodb autoscaling enabled"
     description = "Checks if Auto Scaling or On-Demand is enabled on your DynamoDB tables"
     resource_type = "Dynamodb"
+    risk_level = 'Medium'
 
     regions = self.session.get_available_regions('dynamodb')
 
     for region in regions:
         try:
-            client = self.session.client('dynamodb',region_name=region)
+            client = self.session.client('dynamodb', region_name=region)
 
             dynamodb_tables = list_dynamodb_tables(client)
             for table in dynamodb_tables:
@@ -51,5 +52,6 @@ def dynamodb_autoscaling_enabled(self) -> dict:
         'resource_type': resource_type,
         'Offenders': offenders,
         'Compliance_type': compliance_type,
-        'Description': description
+        'Description': description,
+        'Risk Level': risk_level
     }
