@@ -1,6 +1,7 @@
 import logging
 from OBP_reliability_pillar.elastic_load_balancer.cross_zone_load_balancing_enabled import \
     cross_zone_load_balancing_enabled
+from OBP_reliability_pillar.elastic_load_balancer.elb_deletion_protection import elb_deletion_protection_enabled
 
 logging.basicConfig(level=logging.INFO)
 logger = logging.getLogger()
@@ -16,6 +17,7 @@ def elb_compliance(self) -> list:
 
     response = [
         cross_zone_load_balancing_enabled(self),
+        elb_deletion_protection_enabled(self)
     ]
 
     return response
\ No newline at end of file
