@@ -1,6 +1,8 @@
 from OBP_reliability_pillar.lambdafn.lambda_dlq_check import *
 import logging
 
+from OBP_reliability_pillar.lambdafn.lambda_inside_vpc import lambda_inside_vpc
+
 logging.basicConfig(level=logging.INFO)
 logger = logging.getLogger()
 
@@ -13,7 +15,8 @@ def lambda_compliance(self) -> dict:
     """
     logger.info(" ---Inside lambdafn :: lambda_compliance()")
     response = [
-        lambda_dlq_check(self)
+        lambda_dlq_check(self),
+        lambda_inside_vpc(self),
     ]
 
     return response
\ No newline at end of file
