@@ -21,6 +21,7 @@ def lambda_dlq_check(self) -> dict:
     compliance_type = "Lambda DLQ check"
     description = "Checks whether an AWS Lambda function is configured with a dead-letter queue."
     resource_type = "AWS Lambda"
+    risk_level = 'Medium'
 
     regions = self.session.get_available_regions('lambda')
 
@@ -51,5 +52,6 @@ def lambda_dlq_check(self) -> dict:
         'resource_type': resource_type,
         'Offenders': offenders,
         'Compliance_type': compliance_type,
-        'Description': description
+        'Description': description,
+        'Risk Level': risk_level
     }
\ No newline at end of file
